pub struct ConnectionCreateInvitationOptions {
pub auto_accept: bool,
pub qr: bool,
pub toolbox: bool,
pub multi_use: bool,
pub alias: Option<String>,
}Expand description
Options supplied by the frontend for creating an invitation
Fields
auto_accept: boolWhether we want to auto accept the connection process
qr: boolWhether a QR should be outputted to the user
toolbox: boolWhether it should create a special invitation for the toolbox
multi_use: boolWhether the invitation is reuseable
alias: Option<String>Optional custom alias for the connection