pub struct CredentialOfferOptions {
pub connection_id: String,
pub cred_def_id: String,
pub keys: Vec<String>,
pub values: Vec<String>,
}Expand description
Options when offering a credential
Fields
connection_id: StringConnection id to send the credential to
cred_def_id: StringCredential definition id used a blueprint for the credential
keys: Vec<String>Keys that are in the credential definition that must be filled in
values: Vec<String>Values for the keys these are index-matched