pub struct CredentialOfferResponse {Show 15 fields
pub auto_issue: bool,
pub auto_offer: bool,
pub connection_id: String,
pub created_at: String,
pub credential_definition_id: String,
pub credential_exchange_id: String,
pub credential_offer: Value,
pub credential_offer_dict: Value,
pub credential_proposal_dict: Value,
pub initiator: String,
pub role: String,
pub schema_id: String,
pub state: String,
pub thread_id: String,
pub updated_at: String,
}Expand description
Response structure gotten from the cloudagent when offering a credential
Fields
auto_issue: boolWhether it should auto issue the credential
auto_offer: boolWhether it should auto offer the credential
connection_id: StringThe conneciton id used to send the credential to
created_at: StringWhen the credential offer was created
credential_definition_id: StringThe credential definition id used for the credential
credential_exchange_id: StringReturned credential exchange id used for further credential functionality
credential_offer: ValueThe credential offer object
credential_offer_dict: ValueDictionary of the credential offer
credential_proposal_dict: ValueDictionary of the credential proposal
initiator: StringWho initiated the credential offer
role: StringYour role in the credential offer flow
schema_id: StringWhich schema was used when offering the credential
state: StringWhat the state is in the credential offer flow
thread_id: StringThread id to refer to this offer
updated_at: StringLast time the credential offer was updated