pub struct CredentialDefinitionCreateOptions {
pub schema_id: String,
pub tag: String,
pub support_revocation: bool,
pub revocation_registry_size: Option<i32>,
}Expand description
Options provided when registering a credential definition on the ledger
Fields
schema_id: StringSchema id that the credential definition will be linked to
tag: StringOptional tag used for the credential
If none is supplied default will be used
support_revocation: boolWhether the credential definition supports revocation
revocation_registry_size: Option<i32>The size of the revocation registry, how many credentials fit in the revocation registry