pub struct MultitenancyCreateResponse {
pub created_at: String,
pub key_management_mode: String,
pub settings: Value,
pub token: String,
pub updated_at: String,
pub wallet_id: String,
}Expand description
Response of the create endpoint on the multitenancy module
Fields
created_at: StringTimestamp of when the subwallet was created
key_management_mode: StringThe mode of the key management (managed, unmanaged)
settings: ValueMore wallet information
token: StringJWT
updated_at: StringTimestamp of when the last update happened to the wallet
wallet_id: StringThe wallet id