pub struct OobConnectionCreateInvitationOptions {
pub auto_accept: bool,
pub qr: bool,
pub handshake_protocol: String,
pub multi_use: bool,
pub alias: Option<String>,
}Expand description
Options supplied by the frontend for creating an invitation
Fields
auto_accept: boolWhether we want to auto accept the connection process
qr: boolWhether a QR should be outputted to the user
handshake_protocol: StringTODO: Protocol from enum The handshake protocol to use
multi_use: boolWhether the invitation is reuseable
alias: Option<String>Optional custom alias for the connection