OobConnectionCreateInvitationResponse

Struct OobConnectionCreateInvitationResponse 

pub struct OobConnectionCreateInvitationResponse {
    pub invitation_message_id: String,
    pub invitation: Value,
    pub oob_id: Option<String>,
    pub invitation_url: String,
    pub alias: Option<String>,
}
Response from the cloudagent when an invitation is created

Fields

invitation_message_id: String

the invitation message id generated by the cloudagent this will be used for further functionality

invitation: Value

Invitation object which contains some metadata about the invitation

oob_id: Option<String>

The OOB id that can be used to identify the OOb connection/invite

invitation_url: String

URL that can be parsed by another agent to accept the invitation

alias: Option<String>

Optional alias if it was supplied when creating the invitation