pub struct Predicate(pub String, pub String, pub String);Expand description
A simple predicate enum
The first string is the name of the key/value pair
The second string is the operator that is used >=, <=, =, > or >
The third string is the the value that should be evaluated with
Tuple Fields
0: String1: String2: StringTrait Implementations