pub struct SchemaCreateOptions {
pub name: String,
pub version: String,
pub attributes: Vec<String>,
}Expand description
Options supplied by the frontend to create a schema
Fields
name: StringThe name of the schema
version: StringThe version of the schema
attributes: Vec<String>The attributed that must be registered with the schema