pub struct SchemasGetAllResponse {
pub schema_ids: Vec<String>,
}Expand description
Response from the cloudagent when requesting every schema the cloudagent has registered
Fields
schema_ids: Vec<String>List of all the ids of every schema that the cloudagent has registered