pub struct Did {
pub did: Option<String>,
pub key_type: Option<String>,
pub method: Option<String>,
pub posture: Option<String>,
pub verkey: Option<String>,
}Expand description
Options that are supplied when querying a wallet for DIDs
Fields
did: Option<String>The DID of interest
key_type: Option<String>The key type to query for eg. ed25519, bls12381g2
method: Option<String>DID method to query for. e.g. sov to only fetch indy/sov DIDs Available values : key, sov
posture: Option<String>The DID posture specifying whether the DID is the current public DID, posted to ledger but current public DID, or local to the wallet Available values : public, posted, wallet_only
verkey: Option<String>The verification key of interest