pub struct OobConnectionCreateInvitationResponse {
pub invitation_message_id: String,
pub invitation: Value,
pub oob_id: Option<String>,
pub invitation_url: String,
pub alias: Option<String>,
}Expand description
Response from the cloudagent when an invitation is created
Fields
invitation_message_id: Stringthe invitation message id generated by the cloudagent this will be used for further functionality
invitation: ValueInvitation object which contains some metadata about the invitation
oob_id: Option<String>The OOB id that can be used to identify the OOb connection/invite
invitation_url: StringURL that can be parsed by another agent to accept the invitation
alias: Option<String>Optional alias if it was supplied when creating the invitation